package de.mpg.mpimet.yacgui.xml;

/**
 * Copyright (c) 2013 Max-Planck-Institute for Meteorology, Hamburg.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of Oracle or the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

public enum CouplingOperation {
	
	ACCUMULATE("accumulate"), 
	AVERAGE("average"), 
	MINIMUM("minimum"),
	MAXIMUM("maximum"),
	NONE("none");
	
	private final String name;
	
	private CouplingOperation(String s) {
		name = s;
	}
	
	public boolean equalsName(String otherName) {
		return (otherName == null) ? false : name.equals(otherName);
	}
	
	public static CouplingOperation objectFromString(String name) {
		if (name == null) return null;
		if (name.equals(ACCUMULATE.name)) return ACCUMULATE;
		else if (name.equals(AVERAGE.name)) return AVERAGE;
		else if (name.equals(MINIMUM.name)) return MINIMUM;
		else if (name.equals(MAXIMUM.name)) return MAXIMUM;
		else return NONE;
	}
	
	public static String[] toStringArray() {
		return new String[] { ACCUMULATE.name, AVERAGE.name, MINIMUM.name, MAXIMUM.name, NONE.name };
	}
	
	/**
	 * @return String representation of CouplingOperation, e.g. "average".
	 */
	@Override
	public String toString() {
		return name;
	}
}
