!!
!! @file test_init_final.F90
!!
!! @copyright Copyright  (C)  2013 DKRZ, MPI-M
!!
!! @author Moritz Hanke <hanke@dkrz.de>
!!
!
! Keywords:
! Maintainer: Moritz Hanke <hanke@dkrz.de>
!             Rene Redler <rene.redler@mpimet.mpg.de>
! URL: https://dkrz-sw.gitlab-pages.dkrz.de/yac/
!
! This file is part of YAC.
!
! Redistribution and use in source and binary forms, with or without
! modification, are  permitted provided that the following conditions are
! met:
!
! Redistributions of source code must retain the above copyright notice,
! this list of conditions and the following disclaimer.
!
! Redistributions in binary form must reproduce the above copyright
! notice, this list of conditions and the following disclaimer in the
! documentation and/or other materials provided with the distribution.
!
! Neither the name of the DKRZ GmbH nor the names of its contributors
! may be used to endorse or promote products derived from this software
! without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
! IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
! TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
! PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
! OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
! EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
! PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
! PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
! LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
! NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
! SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
!


#include "test_macros.inc"

program test_init_finalize

  use utest
  use mo_yac_finterface, only : yac_finit, &
                                yac_ffinalize, YAC_MAX_CHARLEN
#ifdef VERBOSE
  use mpi
#endif
  implicit none

  character(len=YAC_MAX_CHARLEN) :: comp_name
  character(len=YAC_MAX_CHARLEN) :: xml_name
  character(len=YAC_MAX_CHARLEN) :: schema_name

  integer  :: comp_id
#ifdef VERBOSE
  integer  :: npes, mype
#endif
#ifdef VERBOSE
  integer  :: ierror
  integer  :: local_communicator
#endif

  call start_test("yac_finit and yac_ffinalize")

  xml_name    = 'coupling.xml'
  schema_name = 'coupling.xsd'
  call yac_finit ( xml_name , schema_name )

  comp_name = 'ICON-ocean'
  call yac_fdef_comp ( comp_name, comp_id )

#ifdef VERBOSE
  call yac_fget_localcomm ( local_communicator, comp_id )

  call MPI_COMM_SIZE ( local_communicator, npes, ierror )
  call MPI_COMM_RANK ( local_communicator, mype, ierror )
  print *, mype, ':', ' we are running on ', npes, ' processors.'
#endif

  call yac_ffinalize ( )

  call stop_test

  call exit_tests

end program test_init_finalize

